@@ -27,7 +27,7 @@ class JobClient(object):
     def call(self, routing_key, body=None,
              exchange='default', exchange_type='topic'):
         if settings.ENVIRONMENT == 'test':
-            return None
+            return job_without_async(routing_key, body)
 
         self.channel.exchange_declare(
             exchange=exchange,
@@ -79,6 +79,13 @@ class JobServer(object):
             )
 
 
+def job_without_async(routing_key, body):
+    if job_methods.get(routing_key):
+        func = job_methods[routing_key]['func']
+        data = json.dumps(body)
+        func(json.loads(data))
+
+
 def job_tasks(routing_key, exchange='default', exchange_type='topic',
               **kwargs):
     def wrapper(func):
